@@ -19,10 +19,10 @@ class divisionCapitalAsker : public boxAsker
 		divisionCapitalAsker(QWidget *parent, KGmap *m, QWidget *w, uint count);
 
 	protected:
-		bool nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer);
-		void setAnswerHook(int userSays);
-		QString getQuestionHook() const;
-		division::askMode askMode() const { return division::eCapital; }
+		bool nextBoxAskerQuestionHook(const QString &division, int i, bool isAnswer) override;
+		void setAnswerHook(int userSays) override;
+		QString getQuestionHook() const override;
+		division::askMode askMode() const override { return division::eCapital; }
 	
 	private:
 		QString p_capital;
